==> Getleft-0.7.5.tgz: Getleft-0.7.5/scripts/Dialogos.tcl <==
###############################################################################
###############################################################################
#####                            Dialogos.tcl
###############################################################################
###############################################################################
##### The contents of this file are adapted from an example in Brent Welch's
##### book "Practical Programming in Tcl/Tk". I made the changes without knowing
##### very well what I was doing, so please, don't blame him for all the
##### weirdness
###############################################################################

namespace eval Dialogos {

###############################################################################
# SeleccionarDirectorio
#    Abre un cuadro de dilogo para seleccionar un directorio, en caso de
#    necesidad lo crea.
###############################################################################
proc SeleccionarDirectorio { } {
    variable fileselect
    global coord
    global tcl_platform
    global dirGetleft
    global env labelButtons labelTitles labelDialogs

    catch {destroy .fileselect}
    set t [toplevel .fileselect -bd 4]

    wm title $t $labelTitles(directory)
    wm resizable $t 0 0

    SetCoordinates
    wm geometry $t +[expr $coord(x)+50]+[expr $coord(y)+50]

    set fdir [frame $t.directorio]
    set ima [image create photo -file [file join "$dirGetleft(images)" arriba.gif]]
    button $fdir.arriba -image $ima -command {
        Dialogos::fileselectList [file dirname $Dialogos::fileselect(dir)]
        Dialogos::fileselectOK
    }
    # Entrada de solo lectura para el directorio actual.

    set ldir [label $fdir.label -text "Actual: "]
    set fileselect(dirEnt) [entry $fdir.entry -relief sunken -width 35\
		 -state disabled -bg white -fg black]
    pack $ldir $fdir.entry -side left
    pack $fdir.arriba -side left -padx 20
    pack $fdir -side top -fill x -pady 5

    # listbox para ver el contenido del directorio.

    set lista [frame $t.lista]
    listbox $lista.list -yscrollcommand [list $lista.scroll set] -bg white -height 10 -fg black
    scrollbar $lista.scroll -command [list $lista.list yview]
    pack $lista.list -side left -fill x -expand true -padx 3
    pack $lista.scroll -side left -fill y
    pack $lista -side top -fill x -expand true -pady 3

    # entry para el nombre del fichero a cargar
    # el valor se guarda en fileselect(path)
    frame $t.top
    label $t.top.l -text "$labelDialogs(dir): " -padx 0
    set e [entry $t.top.path -relief sunken -bg white -fg black\
           -textvariable Dialogos::fileselect(path) -width 27]
    pack $t.top -side top -fill x
    pack $t.top.l -side left
    pack $t.top.path -side left
    set fileselect(pathEnt) $e

    # Set up bindings to invoke OK and Cancel
    bind $e <Return> {
        if {[Dialogos::fileselectOK]==1} {
            set Dialogos::fileselect(done) 1
        }
    }
    bind $e <Control-c> Dialogos::fileselectCancel
    focus $e

    #Botones de Abrir y cancelar

    button $t.top.ok -text $labelButtons(select) -width 10 -height 1 -command {
        if {[Dialogos::fileselectOK]==1} {
            set Dialogos::fileselect(done) 1
        }
    }
    pack $t.top.ok -side right

    frame $t.cancel
    button $t.cancel.cancelar -text $labelButtons(cancel) \
            -command {set Dialogos::fileselect(done) 0} -width 10
    pack $t.cancel.cancelar -side right
    pack $t.cancel -side bottom -fill x

    # A single click to listbox so the user can use arrow keys
    bind $e <Tab> "focus $t.lista.list ; list select set 0 ; break"
    bind $t.lista.list      <Return>         "Dialogos::fileselectTmp ; break"
    bind $t.lista.list 	    <space>          "Dialogos::fileselectTake ; break"
    bind $t.lista.list      <Tab>            "focus $t.top.ok ; break"
    bind $t.lista.list      <Button>         {focus %W}
    bind $t.lista.list      <Double-Button>  {Dialogos::fileselectTmp ; break }
    bind $t                 <KeyPress-Prior> "$t.lista.list yview scroll -1 pages"
    bind $t                 <KeyPress-Next>  "$t.lista.list yview scroll  1 pages"
    bind $t.top.ok          <Tab>            "focus $t.cancel.cancelar ; break"
    bind $t.top.ok          <Return>         "$t.top.ok invoke"
    bind $t.cancel.cancelar <Tab>            "focus $e ; break"
    bind $t.cancel.cancelar <Return>         "$t.cancel.cancelar invoke"

    # Inicializar las variables 

    set fileselect(path) {}
    if {$tcl_platform(os)=="Windows 95"} {
        set dir $dirGetleft(main)
    } else {
        set dir $env(HOME)
    }

    set fileselect(dir) {}
    set fileselect(done) 0

    # Wait for the listbox to be visible so
    # we can provide feedback during the listing
    tkwait visibility .fileselect.lista.list
    fileselectList $dir

    tkwait variable Dialogos::fileselect(done)
    destroy .fileselect
    if {$fileselect(done)==1} {
        return $fileselect(path)
    }
    return
}

###############################################################################
# fileselectList
#    Pone en el cuadro de dilogo los directorios que se encuentran en el
#    directorio actual
#
# Parmetros
#    dir: directorio al que hemos cambiado
##############################################################################
proc fileselectList {dir} {
    variable fileselect

    # Actualizamos el directorio
    set e $fileselect(dirEnt)
    $e config -state normal
    $e delete 0 end
    $e insert 0 $dir
    $e config -state disabled
    $e xview moveto 1

    # Give the user some feedback
    set fileselect(dir) $dir
    .fileselect.lista.list delete 0 end
    .fileselect.lista.list insert 0 Searching...
    update idletasks

    .fileselect.lista.list delete 0

    # Se lee el contenido del directorio
    set ficheros [glob -nocomplain $fileselect(dir)/*]

    # Se pone el directorio padre que esta casi siempre
    if {!([regexp {^((.:)?(/))} $fileselect(dir)])} {
        .fileselect.lista.list insert end ..
    }

    # De lo que hay en el directorio sacamos los directorios
    set dirs {}
    foreach f [lsort $ficheros] {
        if [file isdirectory $f] {
            lappend dirs [file tail $f]
        }
    }

    # Y por fin se muestra el resultado
   foreach f $dirs {
       .fileselect.lista.list insert end $f
   }
   return
}

###############################################################################
# fileselectOk
#    Se le invoca al seleccionar un directorio, en caso necesario
#    pregunta si hay que crearlo
##############################################################################
proc fileselectOK { } {
    variable fileselect
    global labelTitles labelMessages

    if {$fileselect(path)==""} {
        fileselectTake
        if {$fileselect(path)==""} return 
        if {[fileselectOK]==1} {
	      set fileselect(done) 1
        }
        return
    }

   # El directorio padre tiene tratamiento especial
    if {[regexp {\.\./?} $fileselect(path)]} {
        set fileselect(path) {}
        fileselectList [file dirname $fileselect(dir)]
        return
    }

    set path [file join $fileselect(dir) $fileselect(path)]

    if {![file exists $path]} {
	  set decision [tk_messageBox -icon question \
		-message $labelMessages(unknown) -title $labelTitles(unknown) 	\
		-parent .fileselect -type yesno]
	  case $decision {
	      yes {
	          file mkdir $path
	          set fileselect(path) $path
	          set fileselect(done) 1
	          return
	      }
	      no return
	  }
    }
    if [file isdirectory $path] {
        set fileselect(done) 1
        set fileselect(path) $path
    }
    return
}

###############################################################################
# fileselectCancel
#    Procedimiento para cancelar la seleccin
#    
##############################################################################
proc fileselectCancel {} {
    variable fileselect

    set fileselect(done) 1
    set fileselect(path) {}

    return
}

###############################################################################
# fileselectClick
#    Resalta el elemento sobre el que se cliqueo (sic)
#
# Parmetros
#    y: punto de la lista donde se hizo el click
##############################################################################
proc fileselectClick { y } {
    variable fileselect

    set l .fileselect.lista.list
    set fileselect(path) [$l get [$l nearest $Y]]
    focus $fileselect(pathEnt)

    return
}

###############################################################################
# fileselectTake
#    Coge el elemento seleccionado de la lista y lo pone en el 'entry'
##############################################################################
proc fileselectTake {} {
    variable fileselect

    set l .fileselect.lista.list
    set seleccion [$l curselection]
    if {$seleccion!=""} {
        set fileselect(path) [$l get $seleccion]
    }
    focus $fileselect(pathEnt)

    return
}

###############################################################################
# fileselectTmp
#    Se activa cuando se hace doble click sobre un elemento de la lista,
#    recoge el directorio a activar y se encarga de convertirlo en el
#    directorio actual.
##############################################################################
proc fileselectTmp {} {
    variable fileselect

    fileselectTake
    if {[string match \.\. $fileselect(path)] } {
        fileselectList [file dirname $fileselect(dir)]
    } else {
        fileselectList [file join $fileselect(dir) $fileselect(path)]
    }
    set fileselect(path) ""

    return
}
}

==> Getleft-0.7.6.tgz: Getleft-0.7.6/scripts/Dialogos.tcl <==
###############################################################################
###############################################################################
#####                            Dialogos.tcl
###############################################################################
###############################################################################
##### The contents of this file are adapted from an example in Brent Welch's
##### book "Practical Programming in Tcl/Tk". I made the changes without
##### knowing very well what I was doing, so please, don't blame him for all
##### the weirdness.
###############################################################################
##### Copyright 1999 Brent Welch - Andrs Garca.
##### The contents of this file are distributed under the terms of the GPL
###############################################################################

namespace eval Dialogos {

###############################################################################
# SelectDirectory
#    Opens a dialog window which allows the user to choose one directory. If
#    needed, the directory is created.
#
# Returns
#    The full path of the chosen directory.
###############################################################################
proc SelectDirectory { } {
    variable fileselect
    global coord
    global tcl_platform
    global dirGetleft
    global env labelButtons labelTitles labelDialogs

    catch {destroy .fileselect}
    set t [toplevel .fileselect -bd 4]

    wm title $t $labelTitles(directory)
    wm resizable $t 0 0

    SetCoordinates
    wm geometry $t +[expr $coord(x)+50]+[expr $coord(y)+50]

    set fdir [frame $t.directorio]
    set imaArr [image create photo -file [file join "$dirGetleft(images)" arriba.gif]]
    set imaNew [image create photo -file [file join "$dirGetleft(images)"  nuevo.gif]]
    button $fdir.arriba -image $imaArr -command {
        Dialogos::fileselectList [file dirname $Dialogos::fileselect(dir)]
        Dialogos::fileselectOK
    }
    button $fdir.new    -image $imaNew -command ::Dialogos::NewDir
    # Entrada de solo lectura para el directorio actual.

    set ldir [label $fdir.label -text "Actual: "]
    set fileselect(dirEnt) [entry $fdir.entry -relief sunken -width 35\
		 -state disabled -bg white -fg black]
    pack $ldir $fdir.entry -side left
    pack $fdir.arriba $fdir.new -side left -padx 5
    pack $fdir -side top -fill x -pady 5

    # listbox para ver el contenido del directorio.

    set lista [frame $t.lista]
    listbox $lista.list -yscrollcommand [list $lista.scroll set] -bg white -height 10 -fg black
    scrollbar $lista.scroll -command [list $lista.list yview]
    pack $lista.list -side left -fill x -expand true -padx 3
    pack $lista.scroll -side left -fill y
    pack $lista -side top -fill x -expand true -pady 3

    # entry para el nombre del fichero a cargar
    # el valor se guarda en fileselect(path)
    frame $t.top
    label $t.top.l -text "$labelDialogs(dir): " -padx 0
    set e [entry $t.top.path -relief sunken -bg white -fg black\
           -textvariable Dialogos::fileselect(path) -width 27]
    pack $t.top -side top -fill x
    pack $t.top.l -side left
    pack $t.top.path -side left
    set fileselect(pathEnt) $e

    # Set up bindings to invoke OK and Cancel
    bind $e <Return> {
        if {[Dialogos::fileselectOK]==1} {
            set Dialogos::fileselect(done) 1
        }
    }
    bind $e <Control-c> Dialogos::fileselectCancel
    focus $e

    #Botones de Abrir y cancelar

    button $t.top.ok -text $labelButtons(select) -width 10 -height 1 -command {
        if {[Dialogos::fileselectOK]==1} {
            set Dialogos::fileselect(done) 1
        }
    }
    pack $t.top.ok -side right

    frame $t.cancel
    button $t.cancel.cancelar -text $labelButtons(cancel) \
            -command {set Dialogos::fileselect(done) 0} -width 10
    pack $t.cancel.cancelar -side right
    pack $t.cancel -side bottom -fill x

    # A single click to listbox so the user can use arrow keys
    bind $e <Tab> "focus $t.lista.list ; list select set 0 ; break"
    bind $t.lista.list      <Return>         "Dialogos::fileselectTmp ; break"
    bind $t.lista.list 	    <space>          "Dialogos::fileselectTake ; break"
    bind $t.lista.list      <Tab>            "focus $t.top.ok ; break"
    bind $t.lista.list      <Button>         {focus %W}
    bind $t.lista.list      <Double-Button>  {Dialogos::fileselectTmp ; break }
    bind $t                 <KeyPress-Prior> "$t.lista.list yview scroll -1 pages"
    bind $t                 <KeyPress-Next>  "$t.lista.list yview scroll  1 pages"
    bind $t.top.ok          <Tab>            "focus $t.cancel.cancelar ; break"
    bind $t.top.ok          <Return>         "$t.top.ok invoke"
    bind $t.cancel.cancelar <Tab>            "focus $e ; break"
    bind $t.cancel.cancelar <Return>         "$t.cancel.cancelar invoke"

    # Inicializar las variables 

    set fileselect(path) {}
    if {[regexp {Windows} $tcl_platform(os)]} {
        set dir $dirGetleft(main)
    } else {
        set dir $env(HOME)
    }

    set fileselect(dir) {}
    set fileselect(done) 0

    # Wait for the listbox to be visible so
    # we can provide feedback during the listing
    tkwait visibility .fileselect.lista.list
    fileselectList $dir

    tkwait variable Dialogos::fileselect(done)
    destroy .fileselect
    if {$fileselect(done)==1} {
        return $fileselect(path)
    }
    return
}

###############################################################################
# NewDir
#    Opens a dialog box to create a new directory.
###############################################################################
proc NewDir {} {
    variable fileselect
    global labelTitles labelButtons
    global done coord

    SetCoordinates .fileselect

    set dialog  [toplevel .dialog]
    wm title $dialog $labelTitles(newDir)
    wm resizable $dialog 0 0
    wm geometry  $dialog +[expr $coord(x)+100]+[expr $coord(y)+50]

    set done 0

    set marcoEx [frame $dialog.marcoEx]
    set marco   [frame $marcoEx.marco -bd 2 -relief groove]
    set marcoIn [frame $marco.marcoIn]
    set dirEnt  [entry $marcoIn.dirent -relief sunken -fg black -bg white \
            -width 25]

    set botones  [frame  $dialog.botones]
    set aceptar  [button $botones.aceptar  -text $labelButtons(ok)     \
            -width 8 -command {set done 1}]
    set cancelar [button $botones.cancelar -text $labelButtons(cancel) \
            -width 8 -command {set done 0}]

    pack $cancelar -side right -padx 9 -pady 5
    pack $aceptar  -side right -pady 5
    pack $botones  -side bottom -fill x

    pack $dirEnt
    pack $marcoIn -padx 10 -pady 10
    pack $marco -side bottom
    pack $marcoEx -ipadx 10 -ipady 5

    bind $aceptar  <Return> {set done 1}
    bind $cancelar <Return> {set done 0}
    bind $dirEnt   <Return> {set done 1}

    focus $dirEnt
    grab $dialog
    tkwait variable done

    if {$done==1} {
        set dir [$dirEnt get]
        if {$dir!=""} {
            if [catch {file mkdir [file join $fileselect(dir) $dir]} error] {
                tk_messageBox -title $labelTitles(error) -icon error \
                        -message $error
            } else {
                Dialogos::fileselectList $fileselect(dir)
            }
        }
    }
    grab release $dialog
    destroy $dialog
    return
}

###############################################################################
# fileselectList
#    Puts into the dialog box the directories found in the current one.
#
# Parameter
#    dir: Current directory.
##############################################################################
proc fileselectList {dir} {
    variable fileselect

    # Update directory
    set e $fileselect(dirEnt)
    $e config -state normal
    $e delete 0 end
    $e insert 0 $dir
    $e config -state disabled
    $e xview moveto 1

    # Give the user some feedback
    set fileselect(dir) $dir
    .fileselect.lista.list delete 0 end
    .fileselect.lista.list insert 0 Searching...
    update idletasks

    .fileselect.lista.list delete 0

    # Add father directory and scan the current one
    if {!([regexp {^((.:)?(/))$} $fileselect(dir)])} {
        .fileselect.lista.list insert end ..
        set ficheros [glob -nocomplain $fileselect(dir)/*/]
    } else {
        .fileselect.lista.list insert end $fileselect(dir)
        set ficheros [glob -nocomplain /*/]
    }
   # Show results
   foreach f [lsort $ficheros] {
       .fileselect.lista.list insert end [file tail $f]
   }
   return
}

###############################################################################
# fileselectOk
#    This procedure is invoked when a directory is selected, if needed it asks
#    whether the user wants to create it.
##############################################################################
proc fileselectOK { } {
    variable fileselect
    global labelTitles labelMessages

    if {$fileselect(path)==""} {
        fileselectTake
        if {$fileselect(path)==""} return 
        if {[fileselectOK]==1} {
	      set fileselect(done) 1
        }
        return
    }

   # El directorio padre tiene tratamiento especial
    if {[regexp {\.\./?} $fileselect(path)]} {
        set fileselect(path) {}
        fileselectList [file dirname $fileselect(dir)]
        return
    }

    set path [file join $fileselect(dir) $fileselect(path)]

    if {![file exists $path]} {
	  set decision [tk_messageBox -icon question \
		-message $labelMessages(unknown) -title $labelTitles(unknown) 	\
		-parent .fileselect -type yesno]
	  case $decision {
	      yes {
	          file mkdir $path
	          set fileselect(path) $path
	          set fileselect(done) 1
	          return
	      }
	      no return
	  }
    }
    if [file isdirectory $path] {
        set fileselect(done) 1
        set fileselect(path) $path
    }
    return
}

###############################################################################
# fileselectCancel
#    Procedure to cancel the selection
##############################################################################
proc fileselectCancel {} {
    variable fileselect

    set fileselect(done) 1
    set fileselect(path) {}

    return
}

###############################################################################
# fileselectClick
#    Select the clicked item in the directory list.
#
# Parameter
#    y: point where the user clicked.
##############################################################################
proc fileselectClick { y } {
    variable fileselect

    set l .fileselect.lista.list
    set fileselect(path) [$l get [$l nearest $Y]]
    focus $fileselect(pathEnt)

    return
}

###############################################################################
# fileselectTake
#    Takes the selected item from the directory list and puts it in the
#    path entry.
##############################################################################
proc fileselectTake {} {
    variable fileselect

    set l .fileselect.lista.list
    set seleccion [$l curselection]
    if {$seleccion!=""} {
        set fileselect(path) [$l get $seleccion]
    }
    focus $fileselect(pathEnt)

    return
}

###############################################################################
# fileselectTmp
#    Invoked when the user doubleclicks on an item in the directory list,
#    takes the directory and makes it the current one.
##############################################################################
proc fileselectTmp {} {
    variable fileselect

    fileselectTake
    if {[string match \.\. $fileselect(path)] } {
        fileselectList [file dirname $fileselect(dir)]
    } else {
        fileselectList [file join $fileselect(dir) $fileselect(path)]
    }
    set fileselect(path) ""

    return
}
}
